==> fief_server-0.22.2.tar.gz: fief_server-0.22.2/README.md <==
<p align="center">
  <img src="https://raw.githubusercontent.com/fief-dev/.github/main/logos/logo-full-red.svg?sanitize=true" alt="Fief" width="256">
</p>

<p align="center">
    <em>Users and authentication management SaaS</em>
</p>

## Getting started

* Official website: [https://www.fief.dev](https://www.fief.dev)
* Documentation: [https://docs.fief.dev](https://docs.fief.dev)

## Contributing

<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[![All Contributors](https://img.shields.io/badge/all_contributors-15-orange.svg?style=flat-square)](#contributors-)
<!-- ALL-CONTRIBUTORS-BADGE:END -->

All contributions to improve the project are welcome! In particular, bug and documentation fixes are really appreciated.

For new features and larger improvements, we kindly ask you to [**open a discussion first**](https://github.com/orgs/fief-dev/discussions/new?category=ideas) about your idea, what motivates it and how you plan to implement it **before you start working**. It'll avoid frustration on both sides if we decide not to integrate your code in the project.

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tbody>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/shrike71"><img src="https://avatars.githubusercontent.com/u/748514?v=4?s=100" width="100px;" alt="shrike71"/><br /><sub><b>shrike71</b></sub></a><br /><a href="https://github.com/fief-dev/fief/issues?q=author%3Ashrike71" title="Bug reports">🐛</a> <a href="#ideas-shrike71" title="Ideas, Planning, & Feedback">🤔</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://growthengineai.com"><img src="https://avatars.githubusercontent.com/u/4735784?v=4?s=100" width="100px;" alt="trisongz"/><br /><sub><b>trisongz</b></sub></a><br /><a href="#example-trisongz" title="Examples">💡</a> <a href="#ideas-trisongz" title="Ideas, Planning, & Feedback">🤔</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/davidbrochart"><img src="https://avatars.githubusercontent.com/u/4711805?v=4?s=100" width="100px;" alt="David Brochart"/><br /><sub><b>David Brochart</b></sub></a><br /><a href="https://github.com/fief-dev/fief/commits?author=davidbrochart" title="Documentation">📖</a> <a href="https://github.com/fief-dev/fief/commits?author=davidbrochart" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/paolodina"><img src="https://avatars.githubusercontent.com/u/1157401?v=4?s=100" width="100px;" alt="Paolo Dina"/><br /><sub><b>Paolo Dina</b></sub></a><br /><a href="https://github.com/fief-dev/fief/issues?q=author%3Apaolodina" title="Bug reports">🐛</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/duber000"><img src="https://avatars.githubusercontent.com/u/12467861?v=4?s=100" width="100px;" alt="duber000"/><br /><sub><b>duber000</b></sub></a><br /><a href="https://github.com/fief-dev/fief/commits?author=duber000" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://theraloss.com"><img src="https://avatars.githubusercontent.com/u/6277291?v=4?s=100" width="100px;" alt="Danilo Polani"/><br /><sub><b>Danilo Polani</b></sub></a><br /><a href="#translation-danilopolani" title="Translation">🌍</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/ChuckMoe"><img src="https://avatars.githubusercontent.com/u/25569291?v=4?s=100" width="100px;" alt="Moritz"/><br /><sub><b>Moritz</b></sub></a><br /><a href="#translation-ChuckMoe" title="Translation">🌍</a></td>
    </tr>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/plpsanchez"><img src="https://avatars.githubusercontent.com/u/45295173?v=4?s=100" width="100px;" alt="plpsanchez"/><br /><sub><b>plpsanchez</b></sub></a><br /><a href="#translation-plpsanchez" title="Translation">🌍</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/WilliamMayor"><img src="https://avatars.githubusercontent.com/u/403126?v=4?s=100" width="100px;" alt="William Mayor"/><br /><sub><b>William Mayor</b></sub></a><br /><a href="https://github.com/fief-dev/fief/commits?author=WilliamMayor" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="http://ruipoliveira.github.io/"><img src="https://avatars.githubusercontent.com/u/10942886?v=4?s=100" width="100px;" alt="Rui Oliveira"/><br /><sub><b>Rui Oliveira</b></sub></a><br /><a href="#translation-ruipoliveira" title="Translation">🌍</a> <a href="https://github.com/fief-dev/fief/commits?author=ruipoliveira" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://jimscope.is-a.dev"><img src="https://avatars.githubusercontent.com/u/27647007?v=4?s=100" width="100px;" alt="Jimmy Angel Pérez Díaz"/><br /><sub><b>Jimmy Angel Pérez Díaz</b></sub></a><br /><a href="#translation-JimScope" title="Translation">🌍</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://pasteman.dev/"><img src="https://avatars.githubusercontent.com/u/5132385?v=4?s=100" width="100px;" alt="Michał Rosiak"/><br /><sub><b>Michał Rosiak</b></sub></a><br /><a href="#translation-michaldev" title="Translation">🌍</a></td>
      <td align="center" valign="top" width="14.28%"><a href="http://www.olimcc.com"><img src="https://avatars.githubusercontent.com/u/842983?v=4?s=100" width="100px;" alt="olimcc"/><br /><sub><b>olimcc</b></sub></a><br /><a href="#security-olimcc" title="Security">🛡️</a></td>
      <td align="center" valign="top" width="14.28%"><a href="http://joehamman.com"><img src="https://avatars.githubusercontent.com/u/2443309?v=4?s=100" width="100px;" alt="Joe Hamman"/><br /><sub><b>Joe Hamman</b></sub></a><br /><a href="#security-jhamman" title="Security">🛡️</a></td>
    </tr>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/zfei"><img src="https://avatars.githubusercontent.com/u/1736058?v=4?s=100" width="100px;" alt="zfei"/><br /><sub><b>zfei</b></sub></a><br /><a href="#translation-zfei" title="Translation">🌍</a></td>
    </tr>
  </tbody>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

## License

Fief is [fair-code](http://faircode.io) distributed under [**Elastic License 2.0 (ELv2)**](https://github.com/fief-dev/fief/blob/main/LICENSE.md).

==> fief_server-0.23.2.tar.gz: fief_server-0.23.2/README.md <==
<p align="center">
  <img src="https://raw.githubusercontent.com/fief-dev/.github/main/logos/logo-full-red.svg?sanitize=true" alt="Fief" width="256">
</p>

<p align="center">
    <em>Users and authentication management SaaS</em>
</p>

## Getting started

* Official website: [https://www.fief.dev](https://www.fief.dev)
* Documentation: [https://docs.fief.dev](https://docs.fief.dev)

## Contributing

<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[![All Contributors](https://img.shields.io/badge/all_contributors-15-orange.svg?style=flat-square)](#contributors-)
<!-- ALL-CONTRIBUTORS-BADGE:END -->

All contributions to improve the project are welcome! In particular, bug and documentation fixes are really appreciated.

For new features and larger improvements, we kindly ask you to [**open a discussion first**](https://github.com/orgs/fief-dev/discussions/new?category=ideas) about your idea, what motivates it and how you plan to implement it **before you start working**. It'll avoid frustration on both sides if we decide not to integrate your code in the project.

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tbody>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/shrike71"><img src="https://avatars.githubusercontent.com/u/748514?v=4?s=100" width="100px;" alt="shrike71"/><br /><sub><b>shrike71</b></sub></a><br /><a href="https://github.com/fief-dev/fief/issues?q=author%3Ashrike71" title="Bug reports">🐛</a> <a href="#ideas-shrike71" title="Ideas, Planning, & Feedback">🤔</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://growthengineai.com"><img src="https://avatars.githubusercontent.com/u/4735784?v=4?s=100" width="100px;" alt="trisongz"/><br /><sub><b>trisongz</b></sub></a><br /><a href="#example-trisongz" title="Examples">💡</a> <a href="#ideas-trisongz" title="Ideas, Planning, & Feedback">🤔</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/davidbrochart"><img src="https://avatars.githubusercontent.com/u/4711805?v=4?s=100" width="100px;" alt="David Brochart"/><br /><sub><b>David Brochart</b></sub></a><br /><a href="https://github.com/fief-dev/fief/commits?author=davidbrochart" title="Documentation">📖</a> <a href="https://github.com/fief-dev/fief/commits?author=davidbrochart" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/paolodina"><img src="https://avatars.githubusercontent.com/u/1157401?v=4?s=100" width="100px;" alt="Paolo Dina"/><br /><sub><b>Paolo Dina</b></sub></a><br /><a href="https://github.com/fief-dev/fief/issues?q=author%3Apaolodina" title="Bug reports">🐛</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/duber000"><img src="https://avatars.githubusercontent.com/u/12467861?v=4?s=100" width="100px;" alt="duber000"/><br /><sub><b>duber000</b></sub></a><br /><a href="https://github.com/fief-dev/fief/commits?author=duber000" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://theraloss.com"><img src="https://avatars.githubusercontent.com/u/6277291?v=4?s=100" width="100px;" alt="Danilo Polani"/><br /><sub><b>Danilo Polani</b></sub></a><br /><a href="#translation-danilopolani" title="Translation">🌍</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/ChuckMoe"><img src="https://avatars.githubusercontent.com/u/25569291?v=4?s=100" width="100px;" alt="Moritz"/><br /><sub><b>Moritz</b></sub></a><br /><a href="#translation-ChuckMoe" title="Translation">🌍</a></td>
    </tr>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/plpsanchez"><img src="https://avatars.githubusercontent.com/u/45295173?v=4?s=100" width="100px;" alt="plpsanchez"/><br /><sub><b>plpsanchez</b></sub></a><br /><a href="#translation-plpsanchez" title="Translation">🌍</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/WilliamMayor"><img src="https://avatars.githubusercontent.com/u/403126?v=4?s=100" width="100px;" alt="William Mayor"/><br /><sub><b>William Mayor</b></sub></a><br /><a href="https://github.com/fief-dev/fief/commits?author=WilliamMayor" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="http://ruipoliveira.github.io/"><img src="https://avatars.githubusercontent.com/u/10942886?v=4?s=100" width="100px;" alt="Rui Oliveira"/><br /><sub><b>Rui Oliveira</b></sub></a><br /><a href="#translation-ruipoliveira" title="Translation">🌍</a> <a href="https://github.com/fief-dev/fief/commits?author=ruipoliveira" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://jimscope.is-a.dev"><img src="https://avatars.githubusercontent.com/u/27647007?v=4?s=100" width="100px;" alt="Jimmy Angel Pérez Díaz"/><br /><sub><b>Jimmy Angel Pérez Díaz</b></sub></a><br /><a href="#translation-JimScope" title="Translation">🌍</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://pasteman.dev/"><img src="https://avatars.githubusercontent.com/u/5132385?v=4?s=100" width="100px;" alt="Michał Rosiak"/><br /><sub><b>Michał Rosiak</b></sub></a><br /><a href="#translation-michaldev" title="Translation">🌍</a></td>
      <td align="center" valign="top" width="14.28%"><a href="http://www.olimcc.com"><img src="https://avatars.githubusercontent.com/u/842983?v=4?s=100" width="100px;" alt="olimcc"/><br /><sub><b>olimcc</b></sub></a><br /><a href="#security-olimcc" title="Security">🛡️</a></td>
      <td align="center" valign="top" width="14.28%"><a href="http://joehamman.com"><img src="https://avatars.githubusercontent.com/u/2443309?v=4?s=100" width="100px;" alt="Joe Hamman"/><br /><sub><b>Joe Hamman</b></sub></a><br /><a href="#security-jhamman" title="Security">🛡️</a></td>
    </tr>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/zfei"><img src="https://avatars.githubusercontent.com/u/1736058?v=4?s=100" width="100px;" alt="zfei"/><br /><sub><b>zfei</b></sub></a><br /><a href="#translation-zfei" title="Translation">🌍</a> <a href="https://github.com/fief-dev/fief/commits?author=zfei" title="Code">💻</a></td>
    </tr>
  </tbody>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

## License

Fief is [fair-code](http://faircode.io) distributed under [**Elastic License 2.0 (ELv2)**](https://github.com/fief-dev/fief/blob/main/LICENSE.md).
